@@ -5,15 +5,15 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.061 ;
-use IO::Compress::Base::Common  2.061 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Xz 2.061 ;
-use Compress::Raw::Lzma  2.061 ;
+use IO::Compress::Base 2.062 ;
+use IO::Compress::Base::Common  2.062 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Xz 2.062 ;
+use Compress::Raw::Lzma  2.062 ;
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $XzError);
 
-$VERSION = '2.061';
+$VERSION = '2.062';
 $XzError = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -542,7 +542,7 @@ Valid values are 0-9 and C<LZMA_PRESET_DEFAULT>.
 0 is the fastest compression with the lowest memory usage and the lowest
 compression.
 
-9 is the slowest compession with the highest memory usage but with the best
+9 is the slowest compression with the highest memory usage but with the best
 compression.
 
 Defaults to C<LZMA_PRESET_DEFAULT> (6).
@@ -749,7 +749,7 @@ Usage is
 
 Closes the current compressed data stream and starts a new one.
 
-OPTS consists of any of the the options that are available when creating
+OPTS consists of any of the options that are available when creating
 the C<$z> object.
 
 See the L</"Constructor Options"> section for more details.
